@@ -17,10 +17,7 @@ class LoyaltyApi(BaseApi):
                                body):
         """Does a POST request to /v2/loyalty/accounts.
 
-        Creates a loyalty account. For more information, see 
-        [Create a loyalty
-        account](https://developer.squareup.com/docs/docs/loyalty-api/overview/
-        #loyalty-overview-create-account).
+        Creates a loyalty account.
 
         Args:
             body (CreateLoyaltyAccountRequest): An object containing the
@@ -28,7 +25,8 @@ class LoyaltyApi(BaseApi):
                 definition for field details.
 
         Returns:
-            CreateLoyaltyAccountResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -67,10 +65,11 @@ class LoyaltyApi(BaseApi):
                                 body):
         """Does a POST request to /v2/loyalty/accounts/search.
 
-        Searches for loyalty accounts. 
-        In the current implementation, you can search for a loyalty account
-        using the phone number associated with the account. 
-        If no phone number is provided, all loyalty accounts are returned.
+        Searches for loyalty accounts in a loyalty program.  
+        You can search for a loyalty account using the phone number or
+        customer ID associated with the account. To return all loyalty
+        accounts, specify an empty `query` object or omit it entirely.  
+        Search results are sorted by `created_at` in ascending order.
 
         Args:
             body (SearchLoyaltyAccountsRequest): An object containing the
@@ -78,7 +77,8 @@ class LoyaltyApi(BaseApi):
                 definition for field details.
 
         Returns:
-            SearchLoyaltyAccountsResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -124,7 +124,8 @@ class LoyaltyApi(BaseApi):
                 account](#type-LoyaltyAccount) to retrieve.
 
         Returns:
-            RetrieveLoyaltyAccountResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -137,7 +138,7 @@ class LoyaltyApi(BaseApi):
         # Prepare query URL
         _url_path = '/v2/loyalty/accounts/{account_id}'
         _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'account_id': account_id
+            'account_id': {'value': account_id, 'encode': True}
         })
         _query_builder = self.config.get_base_uri()
         _query_builder += _url_path
@@ -174,13 +175,11 @@ class LoyaltyApi(BaseApi):
         - If you are not using the Orders API to manage orders, 
         you first perform a client-side computation to compute the points.  
         For spend-based and visit-based programs, you can call 
-        `CalculateLoyaltyPoints` to compute the points. For more information,
-                see [Loyalty Program
+        [CalculateLoyaltyPoints](#endpoint-Loyalty-CalculateLoyaltyPoints) to
+        compute the points. For more information, 
+        see [Loyalty Program
         Overview](https://developer.squareup.com/docs/docs/loyalty/overview).
-                You then provide the points in a request to this endpoint. 
-        For more information, see [Accumulate
-        points](https://developer.squareup.com/docs/docs/loyalty-api/overview/#
-        accumulate-points).
+                You then provide the points in a request to this endpoint.
 
         Args:
             account_id (string): The [loyalty account](#type-LoyaltyAccount)
@@ -190,7 +189,8 @@ class LoyaltyApi(BaseApi):
                 definition for field details.
 
         Returns:
-            AccumulateLoyaltyPointsResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -203,7 +203,7 @@ class LoyaltyApi(BaseApi):
         # Prepare query URL
         _url_path = '/v2/loyalty/accounts/{account_id}/accumulate'
         _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'account_id': account_id
+            'account_id': {'value': account_id, 'encode': True}
         })
         _query_builder = self.config.get_base_uri()
         _query_builder += _url_path
@@ -236,8 +236,7 @@ class LoyaltyApi(BaseApi):
         Adds points to or subtracts points from a buyer's account. 
         Use this endpoint only when you need to manually adjust points.
         Otherwise, in your application flow, you call 
-        [AccumulateLoyaltyPoints](https://developer.squareup.com/docs/reference
-        /square/loyalty-api/accumulate-loyalty-points) 
+        [AccumulateLoyaltyPoints](#endpoint-Loyalty-AccumulateLoyaltyPoints) 
         to add points when a buyer pays for the purchase.
 
         Args:
@@ -248,7 +247,8 @@ class LoyaltyApi(BaseApi):
                 definition for field details.
 
         Returns:
-            AdjustLoyaltyPointsResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -261,7 +261,7 @@ class LoyaltyApi(BaseApi):
         # Prepare query URL
         _url_path = '/v2/loyalty/accounts/{account_id}/adjust'
         _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'account_id': account_id
+            'account_id': {'value': account_id, 'encode': True}
         })
         _query_builder = self.config.get_base_uri()
         _query_builder += _url_path
@@ -296,11 +296,7 @@ class LoyaltyApi(BaseApi):
         buyer's loyalty account. Each change in the point balance 
         (for example, points earned, points redeemed, and points expired) is 
         recorded in the ledger. Using this endpoint, you can search the ledger
-        for events. 
-        For more information, see 
-        [Loyalty
-        events](https://developer.squareup.com/docs/docs/loyalty-api/overview/#
-        loyalty-events).
+        for events.
 
         Args:
             body (SearchLoyaltyEventsRequest): An object containing the fields
@@ -308,7 +304,8 @@ class LoyaltyApi(BaseApi):
                 definition for field details.
 
         Returns:
-            SearchLoyaltyEventsResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -347,14 +344,11 @@ class LoyaltyApi(BaseApi):
         """Does a GET request to /v2/loyalty/programs.
 
         Returns a list of loyalty programs in the seller's account.
-        Currently, a seller can only have one loyalty program. For more
-        information, see 
-        [Loyalty
-        Overview](https://developer.squareup.com/docs/docs/loyalty/overview).
-        .
+        Currently, a seller can only have one loyalty program.
 
         Returns:
-            ListLoyaltyProgramsResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -412,7 +406,8 @@ class LoyaltyApi(BaseApi):
                 definition for field details.
 
         Returns:
-            CalculateLoyaltyPointsResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -425,7 +420,7 @@ class LoyaltyApi(BaseApi):
         # Prepare query URL
         _url_path = '/v2/loyalty/programs/{program_id}/calculate'
         _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'program_id': program_id
+            'program_id': {'value': program_id, 'encode': True}
         })
         _query_builder = self.config.get_base_uri()
         _query_builder += _url_path
@@ -462,11 +457,7 @@ class LoyaltyApi(BaseApi):
         - If the request includes `order_id`, it adds the reward and related
         discount to the order. 
         After a reward is created, the points are locked and 
-        not available for the buyer to redeem another reward. 
-        For more information, see 
-        [Loyalty
-        rewards](https://developer.squareup.com/docs/docs/loyalty-api/overview/
-        #loyalty-overview-loyalty-rewards).
+        not available for the buyer to redeem another reward.
 
         Args:
             body (CreateLoyaltyRewardRequest): An object containing the fields
@@ -474,7 +465,8 @@ class LoyaltyApi(BaseApi):
                 definition for field details.
 
         Returns:
-            CreateLoyaltyRewardResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -517,12 +509,8 @@ class LoyaltyApi(BaseApi):
         In the current implementation, the endpoint supports search by the
         reward `status`.
         If you know a reward ID, use the 
-        [RetrieveLoyaltyReward](https://developer.squareup.com/docs/reference/s
-        quare/loyalty-api/retrieve-loyalty-reward) endpoint.
-        For more information about loyalty rewards, see 
-        [Loyalty
-        Rewards](https://developer.squareup.com/docs/docs/loyalty-api/overview/
-        #loyalty-rewards).
+        [RetrieveLoyaltyReward](#endpoint-Loyalty-RetrieveLoyaltyReward)
+        endpoint.
 
         Args:
             body (SearchLoyaltyRewardsRequest): An object containing the
@@ -530,7 +518,8 @@ class LoyaltyApi(BaseApi):
                 definition for field details.
 
         Returns:
-            SearchLoyaltyRewardsResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -572,24 +561,19 @@ class LoyaltyApi(BaseApi):
         Deletes a loyalty reward by doing the following:
         - Returns the loyalty points back to the loyalty account.
         - If an order ID was specified when the reward was created 
-        (see
-        [CreateLoyaltyReward](https://developer.squareup.com/docs/reference/squ
-        are/loyalty-api/create-loyalty-reward)), 
+        (see [CreateLoyaltyReward](#endpoint-Loyalty-CreateLoyaltyReward)), 
         it updates the order by removing the reward and related 
         discounts.
         You cannot delete a reward that has reached the terminal state
-        (REDEEMED). 
-        For more information, see 
-        [Loyalty
-        rewards](https://developer.squareup.com/docs/docs/loyalty-api/overview/
-        #loyalty-overview-loyalty-rewards).
+        (REDEEMED).
 
         Args:
             reward_id (string): The ID of the [loyalty
                 reward](#type-LoyaltyReward) to delete.
 
         Returns:
-            DeleteLoyaltyRewardResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -602,7 +586,7 @@ class LoyaltyApi(BaseApi):
         # Prepare query URL
         _url_path = '/v2/loyalty/rewards/{reward_id}'
         _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'reward_id': reward_id
+            'reward_id': {'value': reward_id, 'encode': True}
         })
         _query_builder = self.config.get_base_uri()
         _query_builder += _url_path
@@ -637,7 +621,8 @@ class LoyaltyApi(BaseApi):
                 reward](#type-LoyaltyReward) to retrieve.
 
         Returns:
-            RetrieveLoyaltyRewardResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -650,7 +635,7 @@ class LoyaltyApi(BaseApi):
         # Prepare query URL
         _url_path = '/v2/loyalty/rewards/{reward_id}'
         _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'reward_id': reward_id
+            'reward_id': {'value': reward_id, 'encode': True}
         })
         _query_builder = self.config.get_base_uri()
         _query_builder += _url_path
@@ -680,17 +665,13 @@ class LoyaltyApi(BaseApi):
         """Does a POST request to /v2/loyalty/rewards/{reward_id}/redeem.
 
         Redeems a loyalty reward.
-        The endpoint sets the reward to the terminal state (`REDEEMED`). 
+        The endpoint sets the reward to the `REDEEMED` terminal state. 
         If you are using your own order processing system (not using the 
         Orders API), you call this endpoint after the buyer paid for the 
         purchase.
         After the reward reaches the terminal state, it cannot be deleted. 
         In other words, points used for the reward cannot be returned 
         to the account.
-        For more information, see 
-        [Loyalty
-        rewards](https://developer.squareup.com/docs/docs/loyalty-api/overview/
-        #loyalty-overview-loyalty-rewards).
 
         Args:
             reward_id (string): The ID of the [loyalty
@@ -700,7 +681,8 @@ class LoyaltyApi(BaseApi):
                 definition for field details.
 
         Returns:
-            RedeemLoyaltyRewardResponse: Response from the API. Success
+            ApiResponse: An object with the response value as well as other
+                useful information such as status codes and headers. Success
 
         Raises:
             APIException: When an error occurs while fetching the data from
@@ -713,7 +695,7 @@ class LoyaltyApi(BaseApi):
         # Prepare query URL
         _url_path = '/v2/loyalty/rewards/{reward_id}/redeem'
         _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
-            'reward_id': reward_id
+            'reward_id': {'value': reward_id, 'encode': True}
         })
         _query_builder = self.config.get_base_uri()
         _query_builder += _url_path
